@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2020 by Christoph Reller. All rights reserved.
+# Copyright (c) 2012-2021 by Christoph Reller. All rights reserved.
 
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -38,7 +38,7 @@
     Author: Christoph Reller <christoph.reller@gmail.com>
 """
 
-__version__ = '0.4.9'
+__version__ = '0.4.11'
 
 import contextlib
 import tempfile
@@ -133,7 +133,10 @@ class TikzDirective(Directive):
     optional_arguments = 1
     final_argument_whitespace = True
     option_spec = {'libs': directives.unchanged,
+                   'alt': directives.unchanged,
+                   'align': directives.unchanged,
                    'stringsubst': directives.flag,
+                   'xscale': directives.unchanged,
                    'include': directives.unchanged}
 
     def run(self):
@@ -165,6 +168,9 @@ class TikzDirective(Directive):
                 captionstr = '\n'.join(self.arguments)
 
         node['libs'] = self.options.get('libs', '')
+        node['alt'] = self.options.get('alt', 'Figure made with TikZ')
+        node['align'] = self.options.get('align', 'center')
+        node['xscale'] = self.options.get('xscale', '')
         if 'stringsubst' in self.options:
             node['stringsubst'] = True
         else:
@@ -202,13 +208,25 @@ OUT_EXTENSION = {
     'pdf2svg': 'svg',
     }
 
+LATEX_ALIGN = {
+    'center': 'centering',
+    'left': 'raggedright',
+    'right': 'raggedleft',
+    }
+
+LATEX_ALIGN_ENV = {
+    'center': 'center',
+    'left': 'flushleft',
+    'right': 'flushright',
+    }
+
 
 def cleanup_tikzcode(self, node):
     tikz = node['tikz']
     tikz = tikz.replace('\r\n', '\n')
     tikz = re.sub('^\s*%.*$\n', '', tikz, 0, re.MULTILINE)
     tikz = re.sub('^\s*$\n', '', tikz, 0, re.MULTILINE)
-    if not tikz.startswith('\\begin{tikzpicture}'):
+    if not tikz.startswith('\\begin{tikz'):
         tikz = '\\begin{tikzpicture}\n' + tikz + '\n\\end{tikzpicture}'
     if 'stringsubst' in node:
         tikz = Template(tikz).safe_substitute(wd=getcwd().replace('\\', '/'))
@@ -302,8 +320,7 @@ def html_visit_tikzinline(self, node):
                                   backrefs=[], source=node['tikz'])
         sm.walkabout(self)
     else:
-        self.body.append('<img src="%s" alt="%s"/>' %
-                         (fname, self.encode(node['tikz']).strip()))
+        self.body.append('<img src="%s"/>' % fname)
     raise nodes.SkipNode
 
 
@@ -318,10 +335,14 @@ def html_visit_tikz(self, node):
                                   backrefs=[], source=node['tikz'])
         sm.walkabout(self)
     else:
-        self.body.append(self.starttag(node, 'div', CLASS='figure'))
+        # If scaling option is set, add 'width' attribute
+        scale = ''
+        if node['xscale']:
+            scale = 'width="%s%%"' % (node['xscale'])
+        self.body.append(self.starttag(node, 'div', CLASS='figure', STYLE='text-align: %s' % self.encode(node['align']).strip()))
         self.body.append('<p>')
-        self.body.append('<img src="%s" alt="%s" /></p>\n' %
-                         (fname, self.encode(node['tikz']).strip()))
+        self.body.append('<img %s src="%s" alt="%s" /></p>\n' %
+                         (scale, fname, self.encode(node['alt']).strip()))
 
 
 def html_depart_tikz(self, node):
@@ -348,13 +369,29 @@ def latex_visit_tikzinline(self, node):
 def latex_visit_tikz(self, node):
     tikz = cleanup_tikzcode(self, node)
 
+    align = self.elements['figure_align']
+    if self.no_latex_floats:
+        align = "H"
+
+    # If scaling option is set, enclose in resizebox
+    scale_start = r""
+    scale_end   = r""
+    scale = 0
+    if node['xscale']:
+        scale = int(node['xscale']) * 0.01
+        scale_start= r"\resizebox{" + str(scale) + r"\columnwidth}{!}{"
+        scale_end  = r"}"
+    tikz = scale_start + tikz + scale_end
+
     # Have a caption: enclose in a figure environment.
     if any(isinstance(child, nodes.caption) for child in node.children):
-        self.body.append('\\begin{figure}[htp]\\centering\\capstart' + tikz)
+        self.body.append('\\begin{figure}[%s]\\%s\\capstart' %
+                         (align, LATEX_ALIGN[node['align']]) + tikz)
 
     # No caption: place in a center environment.
     else:
-        self.body.append('\\begin{center}' + tikz + '\\end{center}')
+        env = LATEX_ALIGN_ENV[node['align']]
+        self.body.append('\\begin{%s}' % env + tikz + '\\end{%s}' % env)
 
 
 def latex_depart_tikz(self, node):
